
ChiMera
=======

CarveMe is a python-based tool for genome-scale metabolic model
reconstruction, evaluation and visualization   

Documentation
~~~~~~~~~~~~~

For more details please check: https://github.com/tamascogustavo/chimera

Instalation
~~~~~~~~~~~

Can be easily installed using **pip**:


Additionally, you must install diamond and CPLEX (please check the
documentation for details).

Credits and License
~~~~~~~~~~~~~~~~~~~

Developed by Gustavo Tamasco 

Released under an GLP3 License

